# Generated by roxygen2: do not edit by hand

export(computeIC)
export(dWishart)
export(lmvgamma)
export(mixturewishart)
export(moewishart)
export(plotMCMC)
export(rdirichlet)
export(sampleIW)
export(simData)
importFrom(graphics,legend)
importFrom(graphics,matplot)
importFrom(loo,loo)
importFrom(stats,kmeans)
importFrom(stats,optim)
importFrom(stats,pnorm)
importFrom(stats,rWishart)
importFrom(stats,rbinom)
importFrom(stats,rexp)
importFrom(stats,rgamma)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,toeplitz)
importFrom(utils,combn)
importFrom(utils,tail)
